@@ -34,10 +34,9 @@ MainWindow::MainWindow(const QStringList& args) :
     ui(new Ui::MainWindow)
 {
     ui->setupUi(this);
-
     // setup options
     LUM.clear();
-    QSettings settings("/etc/live-usb-maker-gui-antix/live-usb-maker-gui-antix.conf");
+    QSettings settings("/etc/live-usb-maker-gui-antix/live-usb-maker-gui-antix.conf", QSettings::NativeFormat);
     LUM = settings.value("LUM", "live-usb-maker").toString();
     size_check = settings.value("SizeCheck", 128).toUInt(); // in GB
     qDebug() << "LUM is:" << LUM;
@@ -124,10 +123,10 @@ void MainWindow::makeUsb(const QString &options)
     }
 
     // check amount of io on device before copy, this is in sectors
-    int start_io = cmd.getCmdOut("cat /sys/block/" + device + "/stat |awk '{print $7}'", true).toInt();
+    quint64 start_io = cmd.getCmdOut("cat /sys/block/" + device + "/stat |awk '{print $7}'", true).toULongLong();
     ui->progressBar->setMinimum(start_io);
     qDebug() << "start io is " << start_io;
-    int iso_sectors = source_size.toInt() * 2048; // source_size * 1024 / 512 * 1024
+    quint64 iso_sectors = source_size.toULongLong() * 2048; // source_size * 1024 / 512 * 1024
     ui->progressBar->setMaximum(iso_sectors + start_io);
     qDebug() << "max progress bar is " << ui->progressBar->maximum();
 
@@ -141,6 +140,7 @@ void MainWindow::makeUsb(const QString &options)
                                           "Please wait until the the process is completed").arg(source).arg(device));
     }
     setConnections();
+    stat_file = new QFile("/sys/block/" + device + "/stat");
     qDebug() << cmd.getCmdOut(cmdstr);
 }
 
@@ -173,7 +173,11 @@ void MainWindow::setup()
     // check if running live
     ui->cb_clone_live->setEnabled(isRunningLive());
 
-    //check if datafirst option is available
+    // disable clone running live system when booted encrypted
+    if (QFile::exists("/live/config/encrypted"))
+        ui->cb_clone_live->setEnabled(false);
+
+    // check if datafirst option is available
     if (!cmd.run("live-usb-maker --help | grep -q data-first", true)) {
         ui->comboBoxDataFormat->hide();
         ui->cb_data_first->hide();
@@ -288,7 +292,7 @@ void MainWindow::setConnections()
     connect(&cmd, &QProcess::readyRead, this, &MainWindow::updateOutput);
     connect(&cmd, &QProcess::started, this, &MainWindow::cmdStart);
     connect(&timer, &QTimer::timeout, this, &MainWindow::updateBar);
-    connect(&cmd, static_cast<void (QProcess::*)(int)>(&QProcess::finished), this, &MainWindow::cmdDone);
+    connect(&cmd, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, &MainWindow::cmdDone);
 }
 
 // set proper default mode based on iso contents
@@ -305,15 +309,18 @@ void MainWindow::setDefaultMode(const QString &iso_name)
 
 void MainWindow::updateBar()
 {
-    int current_io = cmd2.getCmdOut("cat /sys/block/" + device + "/stat | awk '{print $7}'", true).toInt();
+    stat_file->open(QIODevice::ReadOnly);
+    QString out = stat_file->readAll();
+    quint64 current_io = out.section(QRegularExpression("\\s+"), 7, 7).toULongLong();
     ui->progressBar->setValue(current_io);
+    stat_file->close();
 }
 
 void MainWindow::updateOutput()
 {
     // remove escape sequences that are not handled by code
     QString out = cmd.readAll();
-    out.remove("[0m").remove("]0;").remove("").remove("").remove("[1000D").remove("[74C|").remove("[?25l").remove("[?25h").remove("[0;36m").remove("[1;37m");
+    out.remove(QRegularExpression("\\[0m|\\]0;|\\|\\|\\[1000D|\\[74C||\\[\\?25l|\\[\\?25h|\\[0;36m|\\[1;37m"));
 //    if (out.contains("[10D[K")) { // escape sequence used to display the progress percentage
 //        out.remove("[10D[K");
 //        ui->outputBox->moveCursor(QTextCursor::StartOfLine);
@@ -394,7 +401,8 @@ void MainWindow::on_buttonSelectSource_clicked()
     QString home = "/home/" + user;
 
     if (!ui->cb_clone_live->isChecked() && !ui->cb_clone_mode->isChecked()) {
-        selected = QFileDialog::getOpenFileName(this, tr("Select an ISO file to write to the USB drive"), home, tr("ISO Files (*.iso);;All Files (*.*)"));
+        selected = QFileDialog::getOpenFileName(this, tr("Select an ISO file to write to the USB drive"), home,
+                                                tr("ISO Files (*.iso);;All Files (*.*)"));
         if (!selected.isEmpty()) {
             ui->buttonSelectSource->setText(selected);
             ui->buttonSelectSource->setProperty("filename", selected);
@@ -542,9 +550,6 @@ void MainWindow::on_rb_normal_clicked()
 
 bool MainWindow::isantiX_mx_family(QString selected)
 {
-    QString cmdstr;
-
-    // make temp folder
     QTemporaryDir tmpdir;
     if (!tmpdir.isValid()) {
         qDebug() << "Could not create temp folder";
@@ -552,7 +557,7 @@ bool MainWindow::isantiX_mx_family(QString selected)
     }
 
     // mount the iso file
-    cmdstr = "mount -o loop " + selected + " " + tmpdir.path();
+    QString cmdstr = "mount -o loop " + selected + " " + tmpdir.path();
     if (system(cmdstr.toUtf8()) != 0) {
         qDebug() << "Could not mount iso file to temp folder";
         return false;
@@ -579,7 +584,7 @@ void MainWindow::on_pushButtonLumLogFile_clicked()
     QString cmd;
 
     // generate temporary log file
-    cmd = "tac /var/log/" + lum.baseName() + ".log | sed \"/^=\\{60\\}=*$/q\" > /tmp/" + lum.baseName() + ".log";
+    cmd = "tac /var/log/" + lum.baseName() + ".log | sed \"/^=\\{60\\}=*$/q\" |tac > /tmp/" + lum.baseName() + ".log ";
     system(cmd.toUtf8());
 
     if (getuid() == 0)
